import logging
import os
import sys
import datetime

logging.basicConfig(stream=sys.stdout, level=logging.INFO)
logger = logging.getLogger(__name__)

AWS_REGION = os.getenv("AWS_REGION", "us-east-1")


# Checking if given date is equal to today's date
def cmp_today_date(date):
    today_date = datetime.datetime.today() - datetime.timedelta(days=1)
    today_date = today_date.strftime("%Y-%m-%d")
    if datetime.datetime.strptime(date, "%Y-%m-%d").date().strftime("%Y-%m-%d") == today_date:
        return True
    else:
        return False


# Get number of likely threats
def get_num_likely_threats(data):
    for dct in data["statistics"]:
        if cmp_today_date(dct["create_date"]):
            return dct["likely_count"]


# Get number of mdr threats
def get_num_mdr_eligible_alerts(data):
    for dct in data["statistics"]:
        if cmp_today_date(dct["create_date"]):
            return dct["mdr_count"]


# Get avg time to determination for likely threats
def get_avg_time_to_determination_likely_threats(data):
    for dct in data["statistics"]:
        if cmp_today_date(dct["create_date"]):
            return round(float(dct["likely_avg_ttr"]), 1)


# Get avg time to determination for mdr threats
def get_avg_time_to_determination_mdr_eligible_alerts(data):
    for dct in data["statistics"]:
        if cmp_today_date(dct["create_date"]):
            return round(float(dct["mdr_avg_ttr"]), 1)


# Getting start and date in the report title
def get_start_and_end_date():
    date_obj = datetime.datetime.today() - datetime.timedelta(days=1)
    prev_date_obj = date_obj - datetime.timedelta(days=1)
    date_obj = date_obj.strftime('%B %d, %Y %-I:%M%p UTC')
    prev_date_obj = prev_date_obj.strftime('%B %d, %Y %-I:%M%p UTC')
    dates_list = [prev_date_obj, date_obj]
    return dates_list


# Getting time range in plots
def get_time_range():
    date_obj = datetime.datetime.today() - datetime.timedelta(days=1)
    date_obj = date_obj.strftime('%b%d%Y')
    month = date_obj[:3]
    day = date_obj[3:5]
    year = date_obj[5:]
    range_str = str(month) + ' ' + str(int(day) - 6) + ' - ' + str(int(day)) + ' ' + str(year)
    return range_str


# Getting data for the pie plots
def get_pie_severity_scores(data, alertType):
    for dct in data["statistics"]:
        if cmp_today_date(dct["create_date"]):
            key = alertType + "_alert_"
            alert_5_count = int(dct[key + "5"]) if dct[key + "5"] else 0
            alert_6_count = int(dct[key + "6"]) if dct[key + "6"] else 0
            alert_7_count = int(dct[key + "7"]) if dct[key + "7"] else 0
            alert_8_count = int(dct[key + "8"]) if dct[key + "8"] else 0
            alert_9_count = int(dct[key + "9"]) if dct[key + "9"] else 0
            alert_10_count = int(dct[key + "10"]) if dct[key + "10"] else 0
            return {'5': alert_5_count,
                    '6': alert_6_count,
                    '7': alert_7_count,
                    '8': alert_8_count,
                    '9': alert_9_count,
                    '10': alert_10_count}
    return {}


# Getting data for the horizontal bar plots
def get_list_hchart(data, alertType, dataType):
    for dct in data["statistics"]:
        if cmp_today_date(dct["create_date"]):
            list = []
            for k in range(1, 7):
                pair = []
                key = alertType + '_' + dataType + '_' + str(k)
                if not (dct[key] == "" or not dct[key]) and not (dct[key + '_cnt'] == "" or not dct[key + '_cnt']):
                    pair.append(dct[key])
                    pair.append(dct[key + '_cnt'])
                    list.append(pair)
            data_types = [x[0] for x in list]
            count = [int(x[1]) for x in list]
            return [data_types, count]
    return [[], []]


# Getting data for the line plots
def get_line_chart(data, yValue):
    ls = []
    for dct in data["statistics"]:
        l = [datetime.datetime.strptime(dct["create_date"], "%Y-%m-%d").date().strftime("%b %-d %Y"), dct[yValue]]
        ls.append(l)
    ls.sort(key=lambda date: datetime.datetime.strptime(date[0], "%b %d %Y"))
    dates = [x[0] for x in ls]
    if '_avg_ttr' in yValue:
        y = [round(float(x[1]), 1) for x in ls]
    else:
        y = [int(x[1]) for x in ls]
    return [dates, y]


# Getting data for the bar plots
def get_bar_chart_severity(data, alertType):
    date_ls = []
    severity_ls = []
    for dct in data["statistics"]:
        date_ls.append(datetime.datetime.strptime(dct["create_date"], "%Y-%m-%d").date().strftime("%b %-d %Y"))
    for x in range(5, 11):
        temp_list = []
        key = alertType + '_alert_' + str(x)
        for dct in data["statistics"]:
            temp_list.append(dct[key])
        temp_list = [x for _, x in sorted(zip(date_ls, temp_list))]
        temp_list = [int(x) if x else 0 for x in temp_list]
        severity_ls.append(temp_list)

    for lst in severity_ls:
        if not all(x == 0 for x in lst):
            break
        severity_ls = []
    date_ls.sort(key=lambda date: datetime.datetime.strptime(date, "%b %d %Y"))
    return [date_ls, severity_ls]
