import matplotlib.pyplot as plt
import numpy as np
from itertools import cycle, islice

def plot_barh_process(lst, alertType):
    fig = plt.figure(figsize=(32,16))
    if not lst[0]:
        return 'src/default_image.png'
    ax=plt.gca()
    x=lst[0]
    y=lst[1]
    bars = ax.barh(x, y, color = 'royalblue', height=0.4)
    urls = ['https://www.bbc.com/news', 'https://www.google.com/', 'https://www.vmware.com/', 'https://www.msn.com/', 'https://www.w3schools.com/', 'https://www.github.com/']
    for bar, url in zip(bars, urls):
        if url:
            bar.set_url(url)
    ax.tick_params(axis='x', which='major', labelsize=36, bottom = False)
    ax.tick_params(axis='y', which='major', labelsize=36, left= False)
    ax.spines['top'].set_visible(False)
    ax.spines['right'].set_visible(False)
    ax.set(xlabel=None)
    ax.set(ylabel=None)
    fig.subplots_adjust(left = 0.25)
    plot_name = 'barh_process_' +alertType+ '.svg'
    fig.savefig(plot_name, format='svg',  bbox_inches='tight')
    if lst[0] and lst[1]:
        return plot_name
    else:
        return 'src/default_image.png'

def plot_bar_severity(lst, alertType):
    fig = plt.figure(figsize=(80,25))
    if not lst[1]:
        return 'src/default_image.png'
    ax=plt.gca()
    width=0.1
    f = lst[1][0]
    e = lst[1][1]
    d = lst[1][2]
    a = lst[1][3]
    b = lst[1][4]
    c = lst[1][5]
    x = np.arange(len(lst[0]))
    date = lst[0]
    # d = np.column_stack((a, b, c, d, e, f))
    # df = pd.DataFrame(d, columns=["A", "B", "C", "D", "E", "F"])
    # df["X"] = date

    bars_1 = plt.bar(x,a, width=0.1, color = '#2475D9')
    bars_2 = plt.bar(x+width,b, width=0.1, color = '#68ACFF' )
    bars_3 = plt.bar(x+width*2,c, width=0.1, color = '#D3E7FF')
    bars_4 = plt.bar(x+width*3,d, width=0.1, color = 'mediumorchid')
    bars_5 = plt.bar(x+width*4,e, width=0.1, color = 'plum')
    bars_6 = plt.bar(x+width*5,f, width=0.1, color = '#E7D5EE' )
    urls = ['https://www.bbc.com/news', 'https://www.google.com/', 'https://www.vmware.com/', 'https://www.msn.com/', 'https://www.w3schools.com/', 'https://www.github.com/']
    for bars in zip(bars_1, bars_2, bars_3,bars_4,bars_5, bars_6):
        for bar, url in zip(bars, urls):
            if url:
                bar.set_url(url)

    # plt.title(r"$\bf{Severity \; scores  \; of \; likely \; threats}$" + "\n November 9-16,2023", fontsize = 100)
    plt.xticks(ticks= x+width,labels=date)
    # plt.yticks(fontsize = 60)
    # ax = plt.gca()
    #ax.legend(bbox_to_anchor=(1.0, 0.0))
    my_labels = ["10 (Priority)",  "9 (Priority)", "8 (Priority)","7 (Eligible)","6 (Eligible)" ,  "5 (Eligible)"]
    ax.legend(loc="lower left", ncol=8, bbox_to_anchor=(0.25, -0.25),  frameon=False, markerfirst=False, labels = my_labels, fontsize = 40)
    ax.spines['top'].set_visible(False)
    ax.spines['right'].set_visible(False)
    ax.grid(axis = 'y', color = "dimgray", linestyle='dashed', alpha = 1, linewidth = 0.9, dashes=(50, 50))
    #ax.grid(color='r', linestyle='-', linewidth=2)
    ax.set(xlabel=None)
    ax.tick_params(axis='x', which='major', labelsize=50, left= False, bottom = False)
    ax.tick_params(axis='y', labelsize=50, left= False)
    #ax.text(x=1.15, y= -70, s = "Severity", fontsize = '38', fontweight='heavy', fontstyle='italic')
    #plt.legend(loc="lower left", ncol=len(df.columns))
    fig.subplots_adjust(bottom = 0.3)
    plot_name = 'bar_chart_severity_'+alertType+'.svg'
    fig.savefig(plot_name, format='svg', bbox_inches='tight')
    if lst[0]:
        return plot_name
    else:
        return 'src/default_image.png'


def plot_pie_severity(dct, alertType):
    if not dct or all(x==0 for x in list(dct.values())):
        return 'src/default_image.png'
    fig = plt.figure(figsize=(80,25))
    ax=plt.gca()
    ls_x=[]
    my_labels=[]
    for k in list(dct.keys()):
        if dct[k]!=0:
            ls_x.append(dct[k])
            if int(k) >=8:
                my_labels.append(str(k) + ' (Priority)')
            else:
                my_labels.append(str(k) + ' (Eligible)')
    x = np.array(ls_x)
    pies= ax.pie(x, radius=1.1, colors = list(islice(cycle(['#D3E7FF', '#68ACFF', '#2475D9', '#E7D5EE', 'mediumorchid']), None, len(x))), labels=my_labels, textprops={'weight':'heavy' , 'fontsize': 50})
    urls = ['https://www.bbc.com/news', 'https://www.google.com/', 'https://www.vmware.com/', 'https://www.msn.com/', 'https://www.w3schools.com/', 'https://www.github.com/']
    for wedge,url in zip(pies[0],urls):
            wedge.set_url(url)
    ax.legend().remove()
    ax.set(xlabel=None)
    ax.set(ylabel=None)
    plot_name = 'pie_severity_' + alertType + '.svg'
    fig.savefig(plot_name, format='svg', bbox_inches='tight')
    return plot_name

def plot_line_chart(lst, alertType, dataType):
    fig = plt.figure(figsize=(80,25))
    if not lst[0]:
        return 'src/default_image.png'
    ax=plt.gca()
    ax.plot(lst[1], lw=7, color = 'mediumorchid')
    ax.spines['top'].set_visible(False)
    ax.spines['right'].set_visible(False)
    ax.grid(axis = 'y', color = "dimgray", linestyle='dashed', alpha = 1, linewidth = 0.9,  dashes=(50, 50))
    ax.set_xticks(ticks = np.arange(len(lst[0])),labels=lst[0])
    ax.legend().remove()
    ax.tick_params(axis='x', which='major', labelsize=60, left= False, bottom = False)
    ax.tick_params(axis='y', labelsize=70, left= False)
    ax.set(xlabel=None)
    plot_name = 'line'+ alertType+ dataType +'.svg'
    fig.savefig(plot_name, format='svg',  bbox_inches='tight')
    return plot_name


def plot_barh_asset(lst, alertType):
    fig = plt.figure(figsize=(32,16))
    if not lst[0]:
        return 'src/default_image.png'
    ax=plt.gca()
    x= lst[0]
    y= lst[1]
    bars = ax.barh(x, y, color = 'mediumorchid', height=0.2)
    urls = ['https://www.bbc.com/news', 'https://www.google.com/', 'https://www.vmware.com/', 'https://www.msn.com/', 'https://www.w3schools.com/', 'https://www.github.com/']
    for bar, url in zip(bars, urls):
        if url:
            bar.set_url(url)

    ax.tick_params(axis='x', which='major', labelsize=36, bottom = False)
    ax.tick_params(axis='y', which='major', labelsize=36, left= False)
    ax.spines['top'].set_visible(False)
    ax.spines['right'].set_visible(False)
    ax.set(xlabel=None)
    ax.set(ylabel=None)
    fig.subplots_adjust(left = 0.25)
    plot_name = 'barh_asset_' +alertType+ '.svg'
    fig.savefig(plot_name, format='svg',  bbox_inches='tight')
    return plot_name

